@@ -10,6 +10,8 @@ class Tests: public QObject
 private:
     QString formatToEnml(QString source);
     QString addEnmlEnvelope(QString source, QString resources = QString(), QString bodyAttrs = QString());
+    QString readFile(QString file);
+    QString getHtmlWithStrippedHtmlComments(QString source);
 
 public:
     Q_INVOKABLE explicit Tests(QObject *parent=Q_NULLPTR);
@@ -18,7 +20,6 @@ public:
 // comment out to debug the only the last test
 private slots:
     void enmlBasicTest();
-    void enmlTidyTest();
     void enmlNixnoteTodoTest();
     void enmlNixnoteImageTest();
     void enmlNixnoteObjectTest();
@@ -26,10 +27,14 @@ private slots:
     void enmlNixnoteTableTest();
     void enmlHtml5TagsTest();
     void latexStringUtilTest();
+    void enmlNixnoteLinkTest2();
+    void enmlHtmlFileTest();
+    void enmlBasicRecursiveTest();
+    void enmlNixnoteLinkTest();
+    void enmlTidyTest();
+    void enmlHtmlCommentTest();
 
 private slots:
-    void enmlNixnoteLinkTest();
-
 };
 
 #endif // NIXNOTE2_TESTS_H
